| quantsig | R Documentation |
This function implements the sigmoidal quantile function estimator, which is a smooth nonparametric quantile function estimator based on a newly defined generalized expectile function.
quantsig(x, p)
x |
a numeric whose sample quantiles are wanted. |
p |
the probability with values in (0,1). |
The estimated quantile.
Alan Hutson, Han Yu
Hutson AD. The generalized sigmoidal quantile function. Communications in Statistics-Simulation and Computation. 2024 Feb 1;53(2):799-813.
x <- c(1, 2, 3, 4, 5, 6, 7, 8, 8, 9)
quantsig(x, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.